@@ -37,6 +37,8 @@ use English; require Exporter;
                 pdlpp_mkgen
 		 );
 
+my $quotation_mark = $^O =~ /MSWin32/i ? '"' : "'";
+
 # Installation locations
 # beware: whereami_any now appends the /Basic or /PDL directory as appropriate
 
@@ -46,7 +48,6 @@ use English; require Exporter;
 
 # Return library locations
 
-
 sub PDL_INCLUDE { '"-I'.whereami_any().'/Core"' };
 sub PDL_TYPEMAP { whereami_any().'/Core/typemap.pdl' };
 # sub PDL_INST_INCLUDE { '-I'.whereami_any().'/Core' };
@@ -404,7 +405,7 @@ sub pdlpp_postamble_int {
 qq|
 
 $pref.pm: $src $core/Types.pm
-	$depbuild\$(PERLRUNINST) \"-MPDL::PP qw/$mod $mod $pref/\" $src
+	$depbuild\$(PERLRUNINST) \"-MPDL::PP qw[$mod $mod $pref]\" $src
 
 $pref.xs: $pref.pm
 	\$(TOUCH) \$@
@@ -425,7 +426,7 @@ sub pdlpp_postamble {
 qq|
 
 $pref.pm: $src
-	\$(PERL) "-I$w" \"-MPDL::PP qw/$mod $mod $pref/\" $src
+	\$(PERL) "-I$w" \"-MPDL::PP qw[$mod $mod $pref]\" $src
 
 $pref.xs: $pref.pm
 	\$(TOUCH) \$@
@@ -436,7 +437,7 @@ $pref\$(OBJ_EXT): $pref.c
 
 install ::
 	\@echo "Updating PDL documentation database...";
-	\$(ABSPERLRUN) -e 'exit if \$\$ENV{DESTDIR}; use PDL::Doc; eval { PDL::Doc::add_module(q{$mod}); }; ';
+	\$(ABSPERLRUN) -e ${quotation_mark}exit if \$\$ENV{DESTDIR}; use PDL::Doc; eval { PDL::Doc::add_module(q{$mod}); }; ${quotation_mark};
 |
 	} (@_)
 }
