@@ -202,7 +202,7 @@ sub mouse_click {
    die "mouse_click: callback could not find image window\n" unless defined $img;
 
    # calculate zoom/aspect ratio factors
-   my $glds = 0; $glds = 1 if $img->dim(0) < 5;  # hack, need verify consistancy
+   my $glds = 0; $glds = 1 if $img->dim(0) < 5;  # hack, need verify consistency
 
    my $zoom_x = $width / $img->dim($glds+0);
    my $zoom_y = $height / $img->dim($glds+1);
@@ -257,7 +257,7 @@ sub resize_window {
    die "resize_window: callback could not find image window\n" unless defined $img;
 
    # calculate zoom/aspect ratio factors
-   my $glds = 0; $glds = 1 if $img->dim(0) < 5;  # hack, need verify consistancy
+   my $glds = 0; $glds = 1 if $img->dim(0) < 5;  # hack, need verify consistency
 
    my $zoom_x = $width / $img->dim($glds+0);
    my $zoom_y = $height / $img->dim($glds+1);
@@ -866,13 +866,13 @@ sub close_imag2d_window {
       }
    }
 
-   print STDERR "close_imag2d_window: started with  " . scalar(@imag2d_list) . " windows.\n";
+   print STDERR "close_imag2d_window: started with  " . scalar(@imag2d_list) . " windows.\n" if $debug;
    if ($found_it) {
       @imag2d_list = grep { $_->{window_id} != $win_id } @imag2d_list;
    } else {
       warn "close_imag2d_window: could not find open window\n";
    }
-   print STDERR "close_imag2d_window: finished with " . scalar(@imag2d_list) . " windows.\n";
+   print STDERR "close_imag2d_window: finished with " . scalar(@imag2d_list) . " windows.\n" if $debug;
 }
 
 #------------------------------------------------------------------------
