@@ -117,6 +117,10 @@ Suffix magic:
   $pdl = rfits('file.fits.gz[3]'); # Read 3rd extension
   @pdls = rfits('file.fits');      # Read primary data and extensions
 
+Tilde expansion:
+  #expand leading ~ to home directory (using glob())
+  $pdl = rfits '~/filename.fits';
+
   $hdr = rfits('file.fits',{data=>0});  # Options hash changes behavior
 
 In list context, C<rfits> reads the primary image and all possible
@@ -165,6 +169,17 @@ time, unpacking such images transparently and returning the data and header
 as if they were part of a normal IMAGE extension.  Setting "expand" to 0
 delivers the binary table, rather than unpacking it into an image.
 
+=item afh (default=1)
+
+By default rfits uses Astro::FITS::Header tied-hash objects to contain
+the FITS header information.  This permits explicit control over FITS
+card information, and conforms well with the FITS specification.  But
+Astro::FITS::Header objects are about 40-60x more memory intensive
+than comparable perl hashes, and also use ~10x more CPU to manage.
+For jobs where header processing performance is important (e.g. reading 
+just the headers of 1,000 FITS files), set afh to 0 to use the legacy parser
+and get a large boost in speed.
+
 =back
 
 FITS image headers are stored in the output PDL and can be retrieved
@@ -302,7 +317,7 @@ reading in a data structure as well.
 
 =cut
 
-our $rfits_options = new PDL::Options( { bscale=>1, data=>1, hdrcpy=>0, expand=>1 } );
+our $rfits_options = new PDL::Options( { bscale=>1, data=>1, hdrcpy=>0, expand=>1, afh=>1 } );
 
 sub PDL::rfitshdr {
   my $class = shift;
@@ -331,7 +346,9 @@ sub PDL::rfits {
   # indicator which cancelled the check for empty primary data array at the end.
   my $explicit_extension = ($file =~ m/\[\d+\]$/ ? 1 : 0);
   $extnum = ( ($file =~ s/\[(\d+)\]$//) ? $1 : 0 );
-  
+
+  $file =~ s/^(~)/glob($1)/e; #tilde expansion.
+
   $file = "gunzip -c $file |" if $file =~ /\.gz$/;    # Handle compression
   $file = "uncompress -c $file |" if $file =~ /\.Z$/;
   
@@ -418,7 +435,7 @@ sub PDL::rfits {
    # does not exist.
    # 
 
-   if($PDL::Astro_FITS_Header) { 
+   if($PDL::Astro_FITS_Header and $opt->{afh}) { 
 
      ## Astro::FITS::Header parsing.  Snarf lines to the END card,
      ## and pass them to Astro::FITS::Header.
@@ -438,7 +455,7 @@ sub PDL::rfits {
    } else {
      
      ## Legacy (straight header-to-hash-ref) parsing.  
-     ## Deprecated but preserved.
+     ## Cheesy but fast.
      
      hdr_legacy: { do {
        no strict 'refs';
@@ -581,6 +598,7 @@ our $type_table = {
     8=>$PDL_B,
     16=>$PDL_S,
     32=>$PDL_L,
+    64=>$PDL_LL,
     -32=>$PDL_F,
     -64=>$PDL_D
 };
@@ -589,6 +607,7 @@ our $type_table_2 = {
     8=>byte,
     16=>short,
     32=>long,
+    64=>longlong,
     -32=>float,
     -64=>double
 };
@@ -638,9 +657,8 @@ sub _rfits_image($$$$) {
   if (!isbigendian() ) {
     # Need to byte swap on little endian machines
     bswap2($pdl) if $pdl->get_datatype == $PDL_S;
-    bswap4($pdl) if $pdl->get_datatype == $PDL_L || 
-      $pdl->get_datatype == $PDL_F;
-    bswap8($pdl) if $pdl->get_datatype == $PDL_D;
+    bswap4($pdl) if $pdl->get_datatype == $PDL_L || $pdl->get_datatype == $PDL_F;
+    bswap8($pdl) if $pdl->get_datatype == $PDL_D || $pdl->get_datatype==$PDL_LL;
   }
   
   if(exists $opt->{bscale}) {
@@ -819,6 +837,7 @@ $PDL::IO::FITS_bintable_handlers = {
   ,'L' => [ byte,    1,     1,     1  ] # logical - treat as byte
   ,'I' => [ short,   2,     2,     2  ] # short (no unsigned shorts?)
   ,'J' => [ long,    4,     4,     4  ] # long
+  ,'K' => [ longlong,8,     8,     8  ] # longlong
   ,'E' => [ float,   4,     4,     4  ] # single-precision
   ,'D' => [ double,  8,     8,     8  ] # double-precision
   ,'C' => [ sub { _nucomplx(float,  eval '@_') }, sub { _rdcomplx(float,  eval '@_') },
@@ -1501,9 +1520,16 @@ sub _rfits_unpack_zimage($$$) {
 	}
     }
 
+    # Copy the ZNAXIS* keywords to NAXIS*
+    foreach (grep /^NAXIS/,keys %$hdr){
+	if (exists($hdr->{'Z'.$_}) && defined($hdr->{'Z'.$_})){
+	    $hdr->{$_} = $hdr->{'Z'.$_};
+	}
+    }
+
     # Clean up the ZFOO extensions and table cruft
-    for my $k(keys %{$pdl->hdr}) {
-	delete $pdl->hdr->{$k} if(
+    for my $k(keys %{$hdr}) {
+	delete $hdr->{$k} if(
 	    $k=~ m/^Z/ ||
 	    $k eq "TFIELDS" ||
 	    $k =~ m/^TTYPE/ ||
@@ -1542,6 +1568,10 @@ Suffix magic:
   # Automatically compress through pipe to compress 
   wfits $pdl, 'filename.fits.Z';  
 
+Tilde expansion:
+  #expand leading ~ to home directory (using glob())
+  wfits $pdl, '~/filename.fits';
+
 =over 3
 
 =item * Ordinary (PDL) data handling: 
@@ -1842,7 +1872,9 @@ sub PDL::wfits {
   }
 
   my ($k, $buff, $off, $ndims, $sz);
-  
+
+  $file =~ s/^(~)/glob($1)/e; # tilde expansion
+
   local $SIG{PIPE};
 
   if ($file =~ /\.gz$/) {            # Handle suffix-style compression
@@ -1859,24 +1891,6 @@ sub PDL::wfits {
   
   #### Figure output type
 
-#  unless( UNIVERSAL::isa($pdl,'PDL') ) {
-#      my $ref = ref($pdl) || "";
-#      if($ref eq 'HASH') {
-#	  my $fh = IO::File->new( $file )
-#	      or barf "Could not open $file\n";
-#	  _wfits_nullhdu($fh);
-#	  # default to binary table if none specified
-#	  my $table_type = exists $pdl->{tbl} ?
-#	      ($pdl->{tbl} =~ m/^a/i ? 'ascii' : 'binary') :
-#	      "binary";
-#	  _wfits_table($fh,$pdl,$table_type);
-#	  $fh->close;
-#	return;
-#     } else {
-#	  barf('wfits: multiple output xtensions not supported\n')
-#     }
-# }
-
   my @outputs = ();
   my $issue_nullhdu;
 
@@ -1921,15 +1935,23 @@ sub PDL::wfits {
 	      $BITPIX =   8 if $pdl->get_datatype == $PDL_B;
 	      $BITPIX =  16 if $pdl->get_datatype == $PDL_S || $pdl->get_datatype == $PDL_US;
 	      $BITPIX =  32 if $pdl->get_datatype == $PDL_L;
+	      $BITPIX =  64 if $pdl->get_datatype == $PDL_LL;
 	      $BITPIX = -32 if $pdl->get_datatype == $PDL_F;
 	      $BITPIX = -64 if $pdl->get_datatype == $PDL_D;
+	      $BITPIX = 8 * PDL::Core::howbig($PDL_IND) if($pdl->get_datatype==$PDL_IND);
 	  }
+	  if ($BITPIX eq "") {
+	      $BITPIX = -64;
+	      warn "wfits: PDL has an unsupported datatype -- defaulting to 64-bit float.\n";
+	  }
+
 	  my $convert = sub { return $_[0] }; # Default - do nothing
-	  $convert = sub {byte($_[0])}   if $BITPIX ==   8;
-	  $convert = sub {short($_[0])}  if $BITPIX ==  16;
-	  $convert = sub {long($_[0])}   if $BITPIX ==  32;
-	  $convert = sub {float($_[0])}  if $BITPIX == -32;
-	  $convert = sub {double($_[0])} if $BITPIX == -64;
+	  $convert = sub {byte($_[0])}     if $BITPIX ==   8;
+	  $convert = sub {short($_[0])}    if $BITPIX ==  16;
+	  $convert = sub {long($_[0])}     if $BITPIX ==  32;
+	  $convert = sub {longlong($_[0])} if $BITPIX == 64;
+	  $convert = sub {float($_[0])}    if $BITPIX == -32;
+	  $convert = sub {double($_[0])}   if $BITPIX == -64;
 	  
 	  # Automatically figure output scaling
 	  
@@ -1940,7 +1962,8 @@ sub PDL::wfits {
 	      my ($dmin,$dmax) = (0, 2**8-1)     if $BITPIX == 8;
 	      ($dmin,$dmax) = (-2**15, 2**15-1)  if $BITPIX == 16;
 	      ($dmin,$dmax) = (-2**31, 2**31-1)  if $BITPIX == 32;
-	      
+	      ($dmin,$dmax) = (-(pdl(longlong,1)<<63), (pdl(longlong,1)<<63)-1) if $BITPIX==64;
+
 	      if ($min<$dmin || $max>$dmax) {
 		  $bzero = $min - $dmin;
 		  $max -= $bzero;
@@ -2182,7 +2205,7 @@ sub PDL::wfits {
 	  if ( !isbigendian() ) { # Need to set a byte swap routine
 	      $bswap = \&bswap2 if $BITPIX==16;
 	      $bswap = \&bswap4 if $BITPIX==32 || $BITPIX==-32;
-	      $bswap = \&bswap8 if $BITPIX==-64;
+	      $bswap = \&bswap8 if $BITPIX==-64 || $BITPIX==64;
 	  }
 	  
 	  # Write FITS data
