@@ -115,9 +115,8 @@ sub init_converter_table {
 				       get => "$conv".'topnm'} }
 
   my @special = (['PNM','NONE','NONE'],
-		 ['PS','pnmtops',
-		  'gs -sDEVICE=ppmraw -sOutputFile=- -q -dNOPAUSE -dBATCH'],
-
+		 ['PS','pnmtops -dpi=100',
+		  'pstopnm -stdout -xborder=0 -yborder=0 -quiet -dpi=100'],
 		 ['GIF','ppmtogif','giftopnm'],
 		 ['IFF','ppmtoilbm','ilbmtoppm']
 		 );
@@ -422,7 +421,7 @@ e.g.
 =item LUT
 
 This is a palette image and the value of this key should be a
-pdl containg an RGB lookup table (3,x), e.g.
+pdl containing an RGB lookup table (3,x), e.g.
 
    LUT        => $lut,
 
@@ -969,7 +968,7 @@ sub chkpdl {
     my ($isrgb,$form) = (0,"");
     my @Dims = $pdl->dims;
     $isrgb = 1 if ($#Dims >= 2) && ($Dims[0] == 3);
-    barf "exspecting 2D or 3D-RGB-interlaced data as input"
+    barf "expecting 2D or 3D-RGB-interlaced data as input"
 	unless ($isrgb || ($#Dims == 1));
 
     $$hints{'COLOR'} = "" unless defined($$hints{'COLOR'});
